cis_config: CisRpcClient Class Reference

cis_config

Public Member Functions | List of all members
CisRpcClient Class Reference

C++ interface to cisRpc_t client-side functionality. The CisRpcClient class is a basic wrapper around the C cisRpc_t structure and associated client-side functions from the CisInterface.h header. It provides the user with C++ style access to basic RPC client operations. More...

`#include <CisInterface.hpp>`

Inheritance diagram for CisRpcClient:

## Public Member Functions
| CisRpcClient (const char *name, const char *outFormat, const char *inFormat)
| Constructor for CisRpcClient. More...
| ~CisRpcClient ()
| Destructor for CisRpcClient. See cis_free in CisInterface.h for details.
int | call (const int nargs,...)
| Send request to an RPC server from the client and wait for a response. See rpcCall in CisInterface.h for details. More...
Public Member Functions inherited from CisRpc
| CisRpc (const char *name, const char *outFormat, const char *inFormat)
| Constructor for CisRpc. More...
| CisRpc (cisRpc_t x)
| Empty constructor for inheritance.
void | _destroy_pi ()
| Alias to allow freeing of underlying C struct at the class level.
| ~CisRpc ()
| Destructor for CisRpc. See cis_free in CisInterface.h for details.
cisRpc_t | pi ()
| Return the cisRpc_t structure. More...
int | send (const int nargs,...)
| Format and send a message to an RPC output queue. See rpcSend from CisInterface.h for details. More...
int | recv (const int nargs,...)
| Receive and parse a message from an RPC input queue. See rpcRecv from CisInterface.h for details. More...

## Detailed Description

C++ interface to cisRpc_t client-side functionality. The CisRpcClient class is a basic wrapper around the C cisRpc_t structure and associated client-side functions from the CisInterface.h header. It provides the user with C++ style access to basic RPC client operations.

## Constructor & Destructor Documentation

## ◆ CisRpcClient()

CisRpcClient::CisRpcClient | ( | const char * | name,
|  | const char * | outFormat,
|  | const char * | inFormat
| ) |  |
| inline

Constructor for CisRpcClient.

Parameters

  [in] | name | constant character pointer name used for input and output queues.
  [in] | outFormat | character pointer to format that should be used for formatting output.
  [in] | inFormat | character pointer to format that should be used for parsing input.

## Member Function Documentation

## ◆ call()

int CisRpcClient::call | ( | const int | nargs,
|  |  | ...
| ) |  |
| inline

Send request to an RPC server from the client and wait for a response. See rpcCall in CisInterface.h for details.

Parameters

  [in] | nargs | int Number of arguments being passed.
  [in,out] | ... | mixed arguments that include those that should be formatted using the output format string, followed by those that should be assigned parameters extracted using the input format string. These that will be assigned should be pointers to memory that has already been allocated.

Returns
  integer specifying if the receive was succesful. Values >= 0 indicate success.

The documentation for this class was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/interface/CisInterface.hpp